@@ -1,7 +1,6 @@
 package Catalyst::Helper::View::MicroMason;
 
 use strict;
-our $VERSION = '0.04_01';
 
 =head1 NAME
 
@@ -36,12 +35,6 @@ L<Catalyst::Response>, L<Catalyst::Helper>
 
 Jonas Alves, C<jgda@cpan.org>
 
-=head1 MAINTAINER
-
-The Catalyst Core Team L<http://www.catalystframework.org/>
-
-Jonathan Rockway C<< <jrockway@cpan.org> >>
-
 =head1 LICENSE
 
 This library is free software . You can redistribute it and/or modify it under
@@ -59,33 +52,27 @@ package [% class %];
 use strict;
 use base 'Catalyst::View::MicroMason';
 
-__PACKAGE__->config(
-    # -Filters      : to use |h and |u
-    # -ExecuteCache : to cache template output
-    # -CompileCache : to cache the templates
-    Mixins => [qw( -Filters -CompileCache )], 
-);
-    
 =head1 NAME
 
 [% class %] - MicroMason View Component
 
 =head1 SYNOPSIS
 
-In your end action:
-
-    $c->forward('[% class %]');
+    Very simple to use
 
 =head1 DESCRIPTION
 
-A description of how to use your view, if you're deviating from the
-default behavior.
+Very nice component.
 
 =head1 AUTHOR
 
+Clever guy
 
 =head1 LICENSE
 
+This library is free software . You can redistribute it and/or modify it under
+the same terms as perl itself.
+
 =cut
 
-1; # magic true value
+1;
